# transmission par signal

## Modulation numerique

on utilise une onde qui est modulée avec le signal d'entrée dans le but de transporter des informations

```

+-----------+  +--------------+
| DTE - DCE |--| Modulateur & |. . . . 
|           |  | Démodulateur |
+-----------+  +--------------+

```

### ~ 

on fait varier l'amplitude du signal pour représenter la donnée binaire.

### FSK (frequency shift keying)

On joue sur la fréquence plutôt que sur l'intensité.

## Déphasage

Plusieurs signaux de même fréquence, mais de biais inégaux.
Le biais est modulo de la fréquence, donc il peut être compté en degré.

### PSK (Phase shift keying)

pour chaque temps,
- 1 : Changement de phase
- 0 : pas de changement de phase

### Variante : QPSK (Quad Phase Shift Keying)

Plutôt que d'utiliser deux phases pour représenter les valeurs binaires,
on utilises 4 phases, chacune représente une combinaison de bits quand on change vers cette phase,

exemple :

```
changement vers : phase 1, phase 2, phase 3, phase 4
valeure décodée : 00,      01,      02,      03
```

### Autres méthodes

#### OFDM (Orthogonal Frequency Division Multiplexing)

Procédé de codage de signaux numériques par répartition
en fréquences orthogonales sous forme de multiples sous-porteuses.

tl;dr On transmet un bloc de données binaires sur un grand nombre de porteuses simultanément.

exemple : wifi 802.11n

## Multiplexage

Techniques de partage d'une ressource, permet de faire passer des informations de plusieurs cannaux par le même canal.

### TDM (Time Division Multiplexing)

Des moments périodiques sont réservés à chacun des canaux.

```
Temps 1

A -+--------------+   +----------------+- A
   |              |   |                |
B -| multiplexeur |-A-| démultiplexeur |- B
   |              |   |                |
C -+--------------+   +----------------+- C

Temps 2

A -+--------------+   +----------------+- A
   |              |   |                |
B -| multiplexeur |-B-| démultiplexeur |- B
   |              |   |                |
C -+--------------+   +----------------+- C

Temps 3

A -+--------------+   +----------------+- A
   |              |   |                |
B -| multiplexeur |-C-| démultiplexeur |- B
   |              |   |                |
C -+--------------+   +----------------+- C

```

### FDM (Frequence Division Multiplexing)

Les communications de chaques émetteurs vont passer en même temps, sur des fréquences différentes combinées.

Exemple : ADSL

```
  0KHz-4KHz    : voix bidirectionnel
  4KHz-20KHz   : -- séparation --
 20KHz-96KHz   : Données montantes
 96KHz-132KHz  : -- Séparation --
132KHz-1000KHz : Données déscendantes
```

## Ligne de transmission

- la ligne de transmission est caractérisée par son débit
- Débit : volume à transmettre par rapport à la durée de transmission -> fréquence de bits
- Unité possible, baud
	- 1 symbole / 1 seconde
	- Modulation QPSK : 4 phases -> 2 bits d'information par cycle

## Taux de transfert & débits lignes

Le taux de transfert est inférieur au débit de la ligne, car certains bits sont consacrés au contrôle de l'information
- Le contrôle de l'information s'applique plusieurs fois (couches OSI)
- Le taux de transfert varie globalement en fonction de :
	- la distance / vitesse de la ligne
	- la synchronicité de la ligne
	- le protocole ...

## Supports

3 catégories de support physiques utilisés :
- support filaires : information sous forme de tension dans un cable
- support aériens :  information sous forme de variation électro-magnétique
- fibres optiques :  information sous forme lumineuse

### Filaire

- blindé contre le bruit, ou non
- ethernet local courte distance

8 catégories

- cat1 & 2 : téléphonie, abandonné, 100m
- cat3 :     16MHz,  10MBps,        100m
...
- cat7 :     600MHz, 10GBps,        100m
- cat8 :     2GHz,   40GBps,         30m

### Optique

- Très haut débit
- monomode et multimode
- multiplexage par longueur d'onde : DWDM, Dense Wavelength Division Multiplexing (plus de débit)

deux formats possibles :
- 40 cannaux de 100Gb
- 80 cannaux de 50Gb

deux types

- MMD, multimode
	- sources lumineuses simples et à faible coût : diode
	- diamètre courants 50µm
	- courtes distances
	- cout faible
	- bande passante limitée
	- ex : Ethernet 1BG, 550m

- SMF, monomode
	- source lumineuses plus élaborée : laser
	- diamètre plus faible 9µm
	- lngues distances
	- cout élevé (fibre + source lumineuse)
	- bande passante très importante
	- ex : ethernet 1Gb, 5Km

## Erreurs de transmission

- perturbations sur le canal de transmission génèrent des erreurs de transmission
- erreurs de transmissions sont inévitables et doivent être traitées
	- Détectées
	- Corrigées

- Les erreurs de transmissions sont généralement traitées au niveau de la couche liaison

### Bit de parité

- utiliser un bit supplémentaire pour envoyer un nombre pair de bits à 1.
- si un nombre impair de bit à 1 est reçu, alors il y a eu une erreur dans la trame.

```

Séquence envoyée

+--------+-+
|10101101|1|
+--------+-+
     |     \_ bit concaténé
     \_______ bits de donnée

- 5 bits à 1 dans les données
- 6 bits à 1


Séquence reçue lors d'un
erreur de transmission

+--------+-+
|10101001|1|
+--------+-+
       \____ bit altéré

- 4 bits à 1 dans les données
- 5 bits à 1

```

- Il est impossible de déterminer le bit défaillant.
- On ne détecte pas un nombre d'erreurs pair.

### CRC (Contrôle de Redondance Cyclique)

- On envoie un Hash à la fin de chaque trame.
- Le code CRC contient des éléments redondants vis à vis des données permettant de détecter la position de l'erreur.

```
Séquence envoyée

+--------+---+
|  DATA  |CRC|
+--------+---+
      |     \_ bits concaténé
      \_______ bits de donnée

- CRC calculé pour cette séquence précise de bits DATA
```

dans des cas simples, le CRC permet de revenir à une DATA cohérente à partir d'une DATA ne correspondant pas à ce CRC.

> Exemples
>
> - Ethernet
> - HDLC (High Level Data Link Control)

### Réseau à commutation de circuits

Un circuit éphémère est établi dans le système lors de la connection

```

       1 -- B
      / .
A -- 2  .
      . .
       3 -- C

circuits existants :
 A - 2 - 1 - B
```

### Réseau à commutation de paquets

Pas de circuits créés dynamiquement par connections
Chaque paquet est intelligament redirigé sur un circuit partagé

```
       1 -- B
      / |
A -- 2  |
      \ |
       3 -- C

circuits existants :
 A - 2   2 - 1
 2 - 3   1 - 3
 1 - B   3 - C

```

Exemple : ATM, FR, IP
